############################################################################
# Script:      Analisis.R
# Objective:   Analizando la estrategia
# Author:      Mario Pisa
# Date:        2019/03/12
# 
# References:  
# TO-DO:       
############################################################################

##################################
# EVALUATING DETAILED PERFORMANCE
##################################
# Trade Related
tab.trades <- tStats %>% 
  mutate(Trades = Num.Trades, 
         Win.Percent = Percent.Positive, 
         Loss.Percent = Percent.Negative, 
         WL.Ratio = Percent.Positive/Percent.Negative) %>% 
  select(Trades, Win.Percent, Loss.Percent, WL.Ratio)
print(t(tab.trades))

# Profit Related
tab.profit <- tStats %>% 
  select(Net.Trading.PL, Gross.Profits, Gross.Losses, Profit.Factor)
print(t(tab.profit))

# Averages
tab.wins <- tStats %>% 
  select(Avg.Trade.PL, Avg.Win.Trade, Avg.Losing.Trade, Avg.WinLoss.Ratio)
print(t(tab.wins))


# Performance Summary
rets <- PortfReturns(Account = account.st)
rownames(rets) <- NULL
charts.PerformanceSummary(rets, colorset = bluefocus)

# Risk Statistics
tab.risk <- table.Arbitrary(rets,
                            metrics = c(
                              "StdDev.annualized",
                              "maxDrawdown",
                              "VaR",
                              "ES"),
                            metricsNames = c(
                              "Annualized StdDev",
                              "Max DrawDown",
                              "Value-at-Risk",
                              "Conditional VaR"))
print(tab.risk)

#############################
# Buy and Hold Performance
#############################
rm.strat("buyHold")
# initialize portfolio and account
initPortf("buyHold", "IBEX", initDate = initDate)
initAcct("buyHold", portfolios = "buyHold",
         initDate = initDate, initEq = initEq)
# place an entry order
CurrentDate <- time(getTxns(Portfolio = portfolio.st, Symbol = "IBEX"))[2]
equity = getEndEq("buyHold", CurrentDate)
ClosePrice <- as.numeric(Cl(IBEX[CurrentDate,]))
addTxn("buyHold", Symbol = "IBEX", TxnDate = CurrentDate, TxnPrice = ClosePrice,
       TxnQty = -1, TxnFees = 0)
# place an exit order
LastDate <- last(time(IBEX))
LastPrice <- as.numeric(Cl(IBEX[LastDate,]))
addTxn("buyHold", Symbol = "IBEX", TxnDate = LastDate, TxnPrice = LastPrice,
       TxnQty = 1 , TxnFees = 0)
# update portfolio and account
updatePortf(Portfolio = "buyHold")
updateAcct(name = "buyHold")
updateEndEq(Account = "buyHold")
chart.Posn("buyHold", Symbol = "IBEX")

# Strategy vs. Market
rets <- PortfReturns(Account = account.st)
rets.bh <- PortfReturns(Account = "buyHold")
returns <- cbind(rets, rets.bh)
names(returns) <- c("rets", "rets.bh")
charts.PerformanceSummary(returns, geometric = FALSE, wealth.index = TRUE, 
                          main = "Strategy vs. Market")

# Relative Performance
for (n in 1:(ncol(returns) - 1)) {
  chart.RelativePerformance(returns[, n], returns[, ncol(returns)], 
                            colorset = c("red", "blue"), lwd = 2, 
                            legend.loc = "topleft")
}

# Portfolio Summary
library(lattice)
pf <- getPortfolio(portfolio.st)
plot(pf$summary, type = "h", col = 4)

# Order Book
ob <- getOrderBook(portfolio.st)

# Maximum Adverse Excursion
for (symbol in symbols) {
  chart.ME(Portfolio = portfolio.st, Symbol = symbol, type = "MAE", 
           scale = "percent", x = "topright")
}

# Maximum Favorable Excursion
for (symbol in symbols) {
  chart.ME(Portfolio = portfolio.st, Symbol = symbol, type = "MFE", 
           scale = "percent")
}

# Equity Curve
equity <- a$summary$End.Eq
plot(equity, main = "Equity Curve")

# Cumulative Returns
rets <- PortfReturns(Account = account.st)
chart.CumReturns(rets, colorset = rich10equal, legend.loc = "topleft", 
                 main = "IBEX Cumulative Returns")

# Distribution Analysis
chart.Boxplot(rets, main = "IBEX Returns", colorset = rich10equal)

